==> haskell-equivalence-0.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.1
id: equivalence-0.3.1-EjOimmInVPjDLykRTK20Mm
key: equivalence-0.3.1-EjOimmInVPjDLykRTK20Mm
license: BSD3
maintainer: paba@di.ku.dk
stability: provisional
homepage: https://bitbucket.org/paba/equivalence/
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
author: Patrick Bahr
exposed: True
exposed-modules:
    Data.Equivalence.STT Data.Equivalence.Monad
abi: 05974db8a920c19fd339ec9c26ef0c02
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/equivalence-0.3.1
hs-libraries: HSequivalence-0.3.1-EjOimmInVPjDLykRTK20Mm
depends:
    STMonadTrans-0.4.1-IBX3w9otdIlBDwkfHvTuPt base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.2
id: equivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
key: equivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
license: BSD3
maintainer: paba@di.ku.dk
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
author: Patrick Bahr
exposed: True
exposed-modules:
    Data.Equivalence.STT Data.Equivalence.Monad
abi: c9bd8a7b2e57f8c6523e1b898296f299
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/equivalence-0.3.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/equivalence-0.3.2
hs-libraries: HSequivalence-0.3.2-AbeI8DCV8sT6eoJWDibbaO
depends:
    STMonadTrans-0.4.3-9CbqniG6MqK81b1oifQGh base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
